=== modified file 'client/drizzleadmin.cc'
--- client/drizzleadmin.cc	2008-08-06 02:14:03 +0000
+++ client/drizzleadmin.cc	2008-08-07 21:28:00 +0000
@@ -20,6 +20,9 @@
 #include <mysys/my_pthread.h>				/* because of signal()	*/
 #include <sys/stat.h>
 
+/* Added this for string translation. */
+#include <libdrizzle/gettext.h>
+
 #define ADMIN_VERSION "8.42"
 #define SHUTDOWN_DEF_TIMEOUT 3600		/* Wait for shutdown */
 
@@ -63,29 +66,29 @@
 
 static struct my_option my_long_options[] =
 {
-  {"help", '?', "Display this help and exit.", 0, 0, 0, GET_NO_ARG,
+  {"help", '?', N_("Display this help and exit."), 0, 0, 0, GET_NO_ARG,
    NO_ARG, 0, 0, 0, 0, 0, 0},
-  {"host", 'h', "Connect to host.", (char**) &host, (char**) &host, 0, GET_STR,
+  {"host", 'h', N_("Connect to host."), (char**) &host, (char**) &host, 0, GET_STR,
    REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
   {"password", 'p',
-   "Password to use when connecting to server. If password is not given it's asked from the tty.",
+   N_("Password to use when connecting to server. If password is not given it's asked from the tty."),
    0, 0, 0, GET_STR, OPT_ARG, 0, 0, 0, 0, 0, 0},
-  {"port", 'P', "Port number to use for connection or 0 for default to, in "
+  {"port", 'P', N_("Port number to use for connection or 0 for default to, in "
    "order of preference, my.cnf, $MYSQL_TCP_PORT, "
-   "built-in default (" STRINGIFY_ARG(MYSQL_PORT) ").",
+   "built-in default (" STRINGIFY_ARG(MYSQL_PORT) ")."),
    (char**) &tcp_port,
    (char**) &tcp_port, 0, GET_UINT, REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
-  {"silent", 's', "Silently exit if one can't connect to server.",
+  {"silent", 's', N_("Silently exit if one can't connect to server."),
    0, 0, 0, GET_NO_ARG, NO_ARG, 0, 0, 0, 0, 0, 0},
 #ifndef DONT_ALLOW_USER_CHANGE
-  {"user", 'u', "User for login if not current user.", (char**) &user,
+  {"user", 'u', N_("User for login if not current user."), (char**) &user,
    (char**) &user, 0, GET_STR_ALLOC, REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
 #endif
-  {"verbose", 'v', "Write more information.", (char**) &opt_verbose,
+  {"verbose", 'v', N_("Write more information."), (char**) &opt_verbose,
    (char**) &opt_verbose, 0, GET_BOOL, NO_ARG, 0, 0, 0, 0, 0, 0},
-  {"version", 'V', "Output version information and exit.", 0, 0, 0, GET_NO_ARG,
+  {"version", 'V', N_("Output version information and exit."), 0, 0, 0, GET_NO_ARG,
    NO_ARG, 0, 0, 0, 0, 0, 0},
-  {"wait", 'w', "Wait and retry if connection is down.", 0, 0, 0, GET_UINT,
+  {"wait", 'w', N_("Wait and retry if connection is down."), 0, 0, 0, GET_UINT,
    OPT_ARG, 0, 0, 0, 0, 0, 0},
   {"connect_timeout", OPT_CONNECT_TIMEOUT, "", (char**) &opt_connect_timeout,
    (char**) &opt_connect_timeout, 0, GET_ULONG, REQUIRED_ARG, 3600*12, 0,
@@ -248,16 +251,16 @@
         if (!host)
           host= (char*) LOCAL_HOST;
 
-        my_printf_error(0,"connect to server at '%s' failed\nerror: '%s'",
+        my_printf_error(0,_("connect to server at '%s' failed\nerror: '%s'"),
         error_flags, host, drizzle_error(drizzle));
 
         if (drizzle_errno(drizzle) == CR_CONN_HOST_ERROR ||
           drizzle_errno(drizzle) == CR_UNKNOWN_HOST)
         {
-          fprintf(stderr,"Check that drizzled is running on %s",host);
-          fprintf(stderr," and that the port is %d.\n",
+          fprintf(stderr,_("Check that drizzled is running on %s"),host);
+          fprintf(stderr,_(" and that the port is %d.\n"),
           tcp_port ? tcp_port: drizzle_port);
-          fprintf(stderr,"You can check this by doing 'telnet %s %d'\n",
+          fprintf(stderr,_("You can check this by doing 'telnet %s %d'\n"),
                   host, tcp_port ? tcp_port: drizzle_port);
         }
       }
@@ -268,14 +271,14 @@
     if ((drizzle_errno(drizzle) != CR_CONN_HOST_ERROR) &&
         (drizzle_errno(drizzle) != CR_CONNECTION_ERROR))
     {
-      fprintf(stderr,"Got error: %s\n", drizzle_error(drizzle));
+      fprintf(stderr,_("Got error: %s\n"), drizzle_error(drizzle));
     }
     else if (!option_silent)
     {
       if (!info)
       {
         info=1;
-        fputs("Waiting for Drizzle server to answer",stderr);
+        fputs(_("Waiting for Drizzle server to answer"),stderr);
         (void) fflush(stderr);
       }
       else
@@ -308,18 +311,18 @@
     case ADMIN_SHUTDOWN:
     {
       if (opt_verbose)
-        printf("shutting down drizzled...\n");
+        printf(_("shutting down drizzled...\n"));
 
       if (drizzle_shutdown(drizzle, SHUTDOWN_DEFAULT))
       {
-        my_printf_error(0, "shutdown failed; error: '%s'", error_flags,
+        my_printf_error(0, _("shutdown failed; error: '%s'"), error_flags,
                         drizzle_error(drizzle));
         return -1;
       }
       drizzle_close(drizzle);	/* Close connection to avoid error messages */
 
       if (opt_verbose)
-        printf("done\n");
+        printf(_("done\n"));
 
       argc=1;             /* Force SHUTDOWN to be the last command */
       break;
@@ -329,7 +332,7 @@
       if (!drizzle_ping(drizzle))
       {
         if (option_silent < 2)
-          puts("drizzled is alive");
+          puts(_("drizzled is alive"));
       }
       else
       {
@@ -337,11 +340,11 @@
         {
           drizzle->reconnect=1;
           if (!drizzle_ping(drizzle))
-            puts("connection was down, but drizzled is now alive");
+            puts(_("connection was down, but drizzled is now alive"));
         }
         else
 	      {
-          my_printf_error(0,"drizzled doesn't answer to ping, error: '%s'",
+          my_printf_error(0,_("drizzled doesn't answer to ping, error: '%s'"),
           error_flags, drizzle_error(drizzle));
           return -1;
         }
@@ -350,7 +353,7 @@
       break;
 
     default:
-      my_printf_error(0, "Unknown command: '%-.60s'", error_flags, argv[0]);
+      my_printf_error(0, _("Unknown command: '%-.60s'"), error_flags, argv[0]);
       return 1;
     }
   }
@@ -359,19 +362,19 @@
 
 static void print_version(void)
 {
-  printf("%s  Ver %s Distrib %s, for %s on %s\n",my_progname,ADMIN_VERSION,
+  printf(_("%s  Ver %s Distrib %s, for %s on %s\n"),my_progname,ADMIN_VERSION,
 	 drizzle_get_client_info(),SYSTEM_TYPE,MACHINE_TYPE);
 }
 
 static void usage(void)
 {
   print_version();
-  puts("Copyright (C) 2000-2006 DRIZZLE AB");
-  puts("This software comes with ABSOLUTELY NO WARRANTY. This is free software,\nand you are welcome to modify and redistribute it under the GPL license\n");
-  puts("Administration program for the drizzled daemon.");
-  printf("Usage: %s [OPTIONS] command command....\n", my_progname);
+  puts(_("Copyright (C) 2000-2008 MySQL AB"));
+  puts(_("This software comes with ABSOLUTELY NO WARRANTY. This is free software,\nand you are welcome to modify and redistribute it under the GPL license\n"));
+  puts(_("Administration program for the drizzled daemon."));
+  printf(_("Usage: %s [OPTIONS] command command....\n"), my_progname);
   my_print_help(my_long_options);
-  puts("\
+  puts(_("\
   ping         Check if server is down\n\
-  shutdown     Take server down\n");
+  shutdown     Take server down\n"));
 }

